@@ -2,7 +2,7 @@
 
 This module is an implementation of the `ACME protocol`_.
 
-.. _`ACME protocol`: https://ietf-wg-acme.github.io/acme
+.. _`ACME protocol`: https://datatracker.ietf.org/doc/html/rfc8555
 
 """
 import sys
@@ -21,10 +21,9 @@ for mod in list(sys.modules):
     if mod == 'josepy' or mod.startswith('josepy.'):
         sys.modules['acme.' + mod.replace('josepy', 'jose', 1)] = sys.modules[mod]
 
-
-if sys.version_info[:2] == (3, 6):
+if sys.version_info[:2] == (3, 7):
     warnings.warn(
-            "Python 3.6 support will be dropped in the next release of "
+            "Python 3.7 support will be dropped in the next planned release of "
             "acme. Please upgrade your Python version.",
             PendingDeprecationWarning,
     )  # pragma: no cover
